function [evd, ezd] = aufgabe3_1(f, d, x)
% AUFGABE3_1 - Berechne Fehler d. Diskretisierung d. 1. Ableitung durch ZD & VD
%   f: Funktionswerte an den St�tzstellen x
%   d: Ableitungen
%   x: St�tzstellen
%   evd, ezd: L1-Diskretisierungsfehler f�r Vorw�rts- bzw. zentrale Differenzen
n = length(f);

% Berechne diskrete Ableitungen f�r Vorw�rts- bzw. zentrale Differenzen ...
vd = (f(3:n) - f(2:n-1)) ./ (x(3:n) - x(2:n-1));
zd = (f(3:n) - f(1:n-2)) ./ (x(3:n) - x(1:n-2));

% ... und daraus die Fehler.
evd = sum(abs(vd(1:n-2) - d(2:n-1))) / (n-2);
ezd = sum(abs(zd(1:n-2) - d(2:n-1))) / (n-2);
